pub fn despawn_all<F>() -> impl Commandwhere
F: QueryFilter,Expand description
A Command that despawns all entities matching a specific QueryFilter.
pub fn despawn_all<F>() -> impl Commandwhere
F: QueryFilter,A Command that despawns all entities matching a specific QueryFilter.